@@ -1,18 +1,10 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2007 Jimmy Gilles <jimmygilles@gmail.com>
- * Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2016,2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
- * Copyright (C) 2011 Philip Greggory Lee <rocketman768@gmail.com>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2007 Jimmy Gilles <jimmygilles@gmail.com>
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2016, 2017 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2011 Philip Greggory Lee <rocketman768@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "keyinfodialog.h"
 
@@ -145,8 +137,8 @@ KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *paren
     mainLayout->addWidget(buttonBox);
 
     connect(m_owtrust, QOverload<int>::of(&QComboBox::activated), this, &KgpgKeyInfo::slotChangeTrust);
-    connect(m_photoid, QOverload<const QString &>::of(&QComboBox::activated), this, &KgpgKeyInfo::slotLoadPhoto);
-    connect(m_email, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl), this, &KgpgKeyInfo::slotOpenUrl);
+    connect(m_photoid, &QComboBox::textActivated, this, &KgpgKeyInfo::slotLoadPhoto);
+    connect(m_email, &KUrlLabel::leftClickedUrl, this, &KgpgKeyInfo::slotOpenUrl);
     connect(keychange, &KGpgChangeKey::done, this, &KgpgKeyInfo::slotApplied);
     connect(m_disable, &QCheckBox::toggled, this, &KgpgKeyInfo::slotDisableKey);
     connect(m_expirationbtn, &QPushButton::clicked, this, &KgpgKeyInfo::slotChangeDate);
@@ -267,9 +259,9 @@ void KgpgKeyInfo::displayKey()
     m_photoid->clear();
 }
 
-void KgpgKeyInfo::slotOpenUrl(const QString &url) const
+void KgpgKeyInfo::slotOpenUrl()
 {
-    QDesktopServices::openUrl(QUrl(url));
+    QDesktopServices::openUrl(QUrl(m_email->url()));
 }
 
 void KgpgKeyInfo::slotLoadPhoto(const QString &uid)
@@ -366,7 +358,7 @@ void KgpgKeyInfo::applyButtonClicked()
 void KgpgKeyInfo::cancelButtonClicked()
 {
 	if (m_keywaschanged && m_node)
-		emit keyNeedsRefresh(m_node);
+		Q_EMIT keyNeedsRefresh(m_node);
 	reject();
 }
 
@@ -376,7 +368,7 @@ void KgpgKeyInfo::slotApplied(int result)
 		KMessageBox::error(this, i18n("Changing key properties failed."), i18n("Key properties"));
 	} else {
 		m_keywaschanged = true;
-		emit keyNeedsRefresh(m_node);
+		Q_EMIT keyNeedsRefresh(m_node);
 		reloadNode();
 	}
 	setControlEnable(true);
